#!/bin/bash

CYLANCE_DIR=/opt/cylance
REG_DIR=${CYLANCE_DIR}/desktop/registry/LocalMachine/software/cylance/desktop
CONF_PATH=${CYLANCE_DIR}/config_defaults.txt
VALUES_XML=${REG_DIR}/values.xml
RETVAL=0


if [ -e ${CONF_PATH} ]; then
    SPLEVEL="$(grep --max-count=1 '^SelfProtectionLevel=' ${CONF_PATH} | awk -F = '{ print $2 }' | sed -e 's/[^0-9]*//g')"
    LOGLEVEL="$(grep --max-count=1 '^LogLevel=' ${CONF_PATH} | awk -F = '{ print $2 }' | sed -e 's/[^0-9]*//g')"
    TOKEN="$(grep --max-count=1 '^InstallToken=' ${CONF_PATH} | awk -F = '{ print $2 }' | sed -e 's/[^a-zA-Z0-9]*//g')"
    VENUEZONE="$(grep --max-count=1 '^VenueZone=' ${CONF_PATH} | awk -F = '{ print $2 }' | sed -e 's/^[[:space:]]*//;s/[[:space:]]*$//')"
    UIMODE="$(grep --max-count=1 '^UiMode=' ${CONF_PATH} | awk -F = '{ print $2 }' | sed -e 's/[^0-9]*//g')"
    DATAPRIVACY="$(grep --max-count=1 '^DataPrivacy=' ${CONF_PATH} | awk -F = '{ print $2 }' | sed -e 's/[^0-9]*//g')"
    UPDATERTEST1="$(grep --max-count=1 '^UpdaterTest1=' ${CONF_PATH} | awk -F = '{ print $2 }' | sed -e 's/^[[:space:]]*//;s/[[:space:]]*$//' | sed -e 's/\d+\.\d+\.\d+\.\d+//g')"
    UPDATERTEST2="$(grep --max-count=1 '^UpdaterTest2=' ${CONF_PATH} | awk -F = '{ print $2 }' | sed -e 's/^[[:space:]]*//;s/[[:space:]]*$//' | sed -e 's/\d+\.\d+\.\d+\.\d+//g')"
    INSTALLREGISTRATIONURL="$(grep --max-count=1 '^InstallRegistrationURL=' ${CONF_PATH} | awk -F = '{ print $2 }' | sed -e 's/^[[:space:]]*//;s/[[:space:]]*$//' | sed -e 's/[\/&]/\\&/g')"
    INSTALLINFINITYURL="$(grep --max-count=1 '^InstallInfinityURL=' ${CONF_PATH} | awk -F = '{ print $2 }' | sed -e 's/^[[:space:]]*//;s/[[:space:]]*$//' | sed -e 's/[\/&]/\\&/g')"
    INSTALLTRUSTEDSUFFIX="$(grep --max-count=1 '^InstallTrustedSuffix=' ${CONF_PATH} | awk -F = '{ print $2 }' | sed -e 's/^[[:space:]]*//;s/[[:space:]]*$//' | sed -e 's/[^-a-zA-Z0-9_~.]*//g')"
    AWS="$(grep --max-count=1 '^AWS=' ${CONF_PATH} | awk -F = '{ print $2 }' | sed -e 's/[^0-9]*//g')"

    if [ "${SPLEVEL}" != "" ]; then
        sed -i -e "s/<[^>]*name=\"SelfProtectionLevel\"[^>]*>[^<]*<\/[^>]*>/<value name=\"SelfProtectionLevel\" type=\"string\">${SPLEVEL}<\/value>/g" \
                  ${VALUES_XML}
    fi
    if [ "${LOGLEVEL}" != "" ]; then
        sed -i -e "s/<[^>]*name=\"LogLevel\"[^>]*>[^<]*<\/[^>]*>/<value name=\"LogLevel\" type=\"string\">${LOGLEVEL}<\/value>/g" \
                  ${VALUES_XML}
    fi
    if [ "${TOKEN}" != "" ]; then
        sed -i -e "s/<[^>]*name=\"InstallToken\"[^>]*>[^<]*<\/[^>]*>/<value name=\"InstallToken\" type=\"string\">${TOKEN}<\/value>/g" \
                  ${VALUES_XML}
    fi
    if [ "${VENUEZONE}" != "" ]; then
        sed -i -e "s/<[^>]*name=\"Zone\"[^>]*>[^<]*<\/[^>]*>/<value name=\"Zone\" type=\"string\">${VENUEZONE}<\/value>/g" \
                  ${VALUES_XML}
    fi
    if [ "${UIMODE}" != "" ]; then
        sed -i -e "s/<[^>]*name=\"UiMode\"[^>]*>[^<]*<\/[^>]*>/<value name=\"UiMode\" type=\"string\">${UIMODE}<\/value>/g" \
                  ${VALUES_XML}
    fi
    if [ "${DATAPRIVACY}" != "" ]; then
        sed -i -e "s/<[^>]*name=\"DataPrivacy\"[^>]*>[^<]*<\/[^>]*>/<value name=\"DataPrivacy\" type=\"string\">${DATAPRIVACY}<\/value>/g" \
                  ${VALUES_XML}
    fi
    if [ "${UPDATERTEST1}" != "" ]; then
        sed -i -e "s/<[^>]*name=\"UpdaterTest1\"[^>]*>[^<]*<\/[^>]*>/<value name=\"UpdaterTest1\" type=\"string\">${UPDATERTEST1}<\/value>/g" \
                  ${VALUES_XML}
    fi
    if [ "${UPDATERTEST2}" != "" ]; then
        sed -i -e "s/<[^>]*name=\"UpdaterTest2\"[^>]*>[^<]*<\/[^>]*>/<value name=\"UpdaterTest2\" type=\"string\">${UPDATERTEST2}<\/value>/g" \
                  ${VALUES_XML}
    fi
    if [ "${INSTALLREGISTRATIONURL}" != "" ]; then
        sed -i -e "s/<[^>]*name=\"InstallRegistrationURL\"[^>]*>[^<]*<\/[^>]*>/<value name=\"InstallRegistrationURL\" type=\"string\">${INSTALLREGISTRATIONURL}<\/value>/g" \
                  ${VALUES_XML}
    fi
    if [ "${INSTALLINFINITYURL}" != "" ]; then
        sed -i -e "s/<[^>]*name=\"InstallInfinityURL\"[^>]*>[^<]*<\/[^>]*>/<value name=\"InstallInfinityURL\" type=\"string\">${INSTALLINFINITYURL}<\/value>/g" \
                  ${VALUES_XML}
    fi
    if [ "${INSTALLTRUSTEDSUFFIX}" != "" ]; then
        sed -i -e "s/<[^>]*name=\"InstallTrustedSuffix\"[^>]*>[^<]*<\/[^>]*>/<value name=\"InstallTrustedSuffix\" type=\"string\">${INSTALLTRUSTEDSUFFIX}<\/value>/g" \
                  ${VALUES_XML}
    fi
    if [ "${AWS}" != "" ]; then
        sed -i -e "s/<[^>]*name=\"AwsEc2Instance\"[^>]*>[^<]*<\/[^>]*>/<value name=\"AwsEc2Instance\" type=\"string\">${AWS}<\/value>/g" \
                  ${VALUES_XML}
    fi
else
    RETVAL=1
fi

exit ${RETVAL}
